<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="5">
            <el-form-item label="分组名称">
              <el-input maxlength="128" clearable placeholder="请输入分组名称" v-model="querys[0].value"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="分组标识">
              <el-input maxlength="32" clearable placeholder="请输入分组标识" v-model="querys[1].value"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete" type="danger"
            style="margin-left: 10px">删除</el-button>
        </el-popconfirm>
      </div>
      <el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column fixed type="index" width="55" label="序号"></el-table-column>
        <el-table-column fixed mini-width="120" prop="groupName" label="分组名称" show-overflow-tooltip></el-table-column>
        <el-table-column min-width="120" prop="groupCode" label="分组标识" show-overflow-tooltip></el-table-column>
        <el-table-column min-width="120" prop="memo" label="备注" show-overflow-tooltip></el-table-column>
        <el-table-column fixed="right" label="操作" width="200">
          <template slot-scope="scope">
            <el-button @click="handleClick(scope.row)" size="small">关联设备</el-button>
          </template>
        </el-table-column>
      </el-table>
      <el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" :current-page="queryParam.pageBean.page"
        :page-sizes="[20, 30, 40, 50]" :page-size="queryParam.pageBean.pageSize"
        layout="total, sizes, prev, pager, next, jumper" :total="total"></el-pagination>
    </div>
    <Grouping-manage-dialog ref="formModal" @loadData="loadData"></Grouping-manage-dialog>
    <AssociatedEquipmentDialog v-if="StshowFormDias" @loadData="loadData" @closeStshowForm="closeStshowForm"
      :StshowFormDias="StshowFormDias" :pId="pId"></AssociatedEquipmentDialog>
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import GroupingManageDialog from '@/views/Device/deviceManage/components/GroupingManageDialog'
import AssociatedEquipmentDialog from '@/views/Device/deviceManage/components/AssociatedEquipmentDialog'
import GroupingManage from '@/api/device/GroupingManage.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
export default {
  name: 'GroupingManage',
  components: {
    GroupingManageDialog,
    AssociatedEquipmentDialog,
  },
  mixins: [TableMixin],
  data() {
    return {
      url: {
        delete: '/device/group/info/',
      },
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'groupName',
          relation: 'AND',
          value: '',
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'groupCode',
          relation: 'AND',
          value: '',
        },
      ],
      StshowFormDias: false,
      pId: '',
    }
  },
  created() { },
  mounted() { },
  methods: {
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      GroupingManage.groupList(this.queryParam, (res) => {
        // console.log(res, 'res')
        this.total = res.total
        this.tableData = res.rows
        this.$set(this.tableData)
        this.loading = false
      })
    },
    // 修改
    handleUpdate(row) {
      // console.log(row.id)
      this.$refs.formModal.Update(row)
    },
    // 关联设备
    handleClick(item) {
      this.pId = item.id
      this.StshowFormDias = true
    },
    closeStshowForm() {
      this.pId = ''
      this.StshowFormDias = false
    },
  },
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
